<?php
/**
 * @category      module
 *
 * @author        eKomi
 *
 * @see           https://www.ekomi.de
 *
 * @copyright (C) eKomi 2001-2017
 */

/**
 * Class ekomiPRCMainWidget.
 */
class ekomiSmartWidget extends oxWidget
{
    /**
     * Names of components (classes) that are initiated and executed.
     * before any other regular operation.
     *
     * @TODO: Enter components You need for the widget to be loaded. As example ... array('oxcmp_cur' => 1, ...);
     *
     * @var array
     */
    protected $_aComponentNames = array('oxcmp_user' => 1);

    /**
     * Widget template name.
     *
     * @var string
     */
    protected $_sThisTemplate = 'ekomismartwidget.tpl';
    protected $_oArticle;
    protected $_pluginConfig;

    /**
     * Executes parent::render().
     * Returns name of template file to render.
     *
     * @return string current template file name
     */
    public function render()
    {
        parent::render();

        $oxid = $this->getViewParameter('oxid');
        $oArticle = oxNew('oxarticle');

        $oArticle->load($oxid);

        $this->_oArticle = $oArticle;
        $this->_pluginConfig = oxRegistry::getConfig();

        return $this->_sThisTemplate;
    }

    /**
     * Checks if smart widget is enabled.
     *
     * @return mixed
     */
    public function isShowPrcEnable()
    {
        return $this->_pluginConfig->getShopConfVar('ekomiConfigShowPrcWidget');
    }

    /**
     * Gets shop id.
     *
     * @return string
     */
    public function getShopId()
    {
        return trim($this->_pluginConfig->getShopConfVar('ekomiConfigShopId'));
    }

    /**
     * Gets product identifier.
     *
     * @return string
     */
    public function getProductIdentifier()
    {
        $productIdentifier = '';
        if ($this->_oArticle) {
            $configuredProductIdentifier = trim($this->_pluginConfig->getShopConfVar('ekomiConfigProductIdentifier'));
            switch ($configuredProductIdentifier) {
                case ekomiIntegrationModule::ARTICLE_EAN:
                    $productIdentifier = $this->_oArticle->oxarticles__oxean->value;
                    break;
                case ekomiIntegrationModule::ARTICLE_DIST_EAN:
                    $productIdentifier = $this->_oArticle->oxarticles__oxdistean->value;
                    break;
                case ekomiIntegrationModule::ARTICLE_MPN:
                    $productIdentifier = $this->_oArticle->oxarticles__oxmpn->value;
                    break;
                default:
                    $productIdentifier = $this->_oArticle->oxarticles__oxartnum->value;
            }
        }

        return $productIdentifier;
    }

    /**
     * Gets smart widget token.
     *
     * @return string
     */
    public function getPrcWidgetToken()
    {
        return trim($this->_pluginConfig->getShopConfVar('ekomiConfigPrcWidgetToken'));
    }
}
