<?php

/**
 * PAYONE OXID Connector is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PAYONE OXID Connector is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with PAYONE OXID Connector.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @see           http://www.payone.de
 *
 * @copyright (C) Payone GmbH
 *
 * @version       OXID eShop CE
 */
class ekomiIntegrationHelper extends oxBase
{
    /**
     * Flags if shop uses registry.
     *
     * @var static boolean
     */
    protected static $_blUseRegistry = null;

    /**
     * Building essential stuff.
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Gets http headers for api.
     *
     * @param int    $shopId
     * @param string $shopSecret
     *
     * @return array
     */
    public function getHttpHeader($shopId, $shopSecret)
    {
        $httpHeader = array(
            'shop-id: ' . $shopId,
            'interface-password: ' . $shopSecret,
        );

        return $httpHeader;
    }

    /**
     * Gets data time limit.
     *
     * @param array $configurations
     *
     * @return string
     *
     * @throws Exception
     */
    public function getDateTimeLimit($configurations)
    {
        if (!empty($configurations['lastExportedOrderTimestamp'])) {
            return $configurations['lastExportedOrderTimestamp'];
        } else {
            $dateLimit = new DateTime("-{$configurations['turnaroundTime']} day");

            return $dateLimit->format('Y-m-d') . ' 00:00:00';
        }
    }

    /**
     * Makes a curl request.
     *
     * @param string $requestUrl  Api End point url
     * @param string $requestType Api Request type
     * @param array  $httpHeader  Header
     * @param string $postFields  The post data to send
     *
     * @return mixed|string
     */
    public function doCurl($requestUrl, $requestType, $httpHeader = array(), $postFields = '')
    {
        try {
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $requestUrl);
            curl_setopt($ch, CURLOPT_HEADER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $requestType);
            if (!empty($httpHeader)) {
                curl_setopt($ch, CURLOPT_HTTPHEADER, $httpHeader);
            }

            if (!empty($postFields)) {
                curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields);
            }

            $response = curl_exec($ch);

            curl_close($ch);

            return $response;
        } catch (Exception $exception) {
            return $exception->getMessage();
        }
    }

    /**
     * Returns a factory instance of given object.
     *
     * @param string $sName
     *
     * @return object
     */
    public function getFactoryObject($sName)
    {
        return oxNew($sName);
    }
}
